# erudition

[![Documentation Status](https://readthedocs.org/projects/erudition/badge/?version=latest)](https://erudition.readthedocs.io/en/latest)
[![codeclimate](https://img.shields.io/codeclimate/maintainability/endremborza/erudition.svg)](https://codeclimate.com/github/endremborza/erudition)
[![codecov](https://img.shields.io/codecov/c/github/endremborza/erudition)](https://codecov.io/gh/endremborza/erudition)
[![pypi](https://img.shields.io/pypi/v/erudition.svg)](https://pypi.org/project/erudition/)

add keywords to pyproject.toml
